==> labplot_1.4.0.orig.tar.gz: LabPlot-1.4.0/src/pixmaps/pixmap.h <==
#include "arrange.xpm"
#include "arrow_down.xpm"
#include "arrow_left.xpm"
#include "arrow_right.xpm"
#include "arrow_up.xpm"
#include "autoscaleall.xpm"
#include "autoscalex.xpm"
#include "autoscaley.xpm"
#include "autoscalez.xpm"
#include "average.xpm"
#include "axes.xpm"
#include "baseline.xpm"
#include "clear.xpm"
#include "convolution.xpm"
#include "deletePlot.xpm"
#include "differences.xpm"
#include "ellipse.xpm"
#include "examples.xpm"
#include "explorer.xpm"
#include "exportim.xpm"
#include "exportps.xpm"
#include "export.xpm"
#include "fft.xpm"
#include "fit.xpm"
#include "fullscreen.xpm"
#include "gl.xpm"
#include "graphs.xpm"
#include "graph.xpm"
#include "grass.xpm"
#include "help.xpm"
#include "histogram.xpm"
#include "imagepro.xpm"
#include "image.xpm"
#include "import.xpm"
#include "integration.xpm"
#include "interpolation.xpm"
#include "label.xpm"
#include "legend.xpm"
#include "line.xpm"
#include "mag_glass.xpm"
#include "mousepan.xpm"
#include "new3DData.xpm"
#include "new3DFunction.xpm"
#include "newData.xpm"
#include "newFunction.xpm"
#include "objects.xpm"
#include "operations.xpm"
#include "overlay.xpm"
#include "plot2d.xpm"
#include "plot3d.xpm"
#include "plotpie.xpm"
#include "plotpolar.xpm"
#include "plotqwt3d.xpm"
#include "plotsurface.xpm"
#include "plotternary.xpm"
#include "project.xpm"
#include "prune.xpm"
#include "qsa.xpm"
#include "rect.xpm"
#include "region.xpm"
#include "regression.xpm"
#include "saveAs.xpm"
#include "scalexdown.xpm"
#include "scalexup.xpm"
#include "scaleydown.xpm"
#include "scaleyup.xpm"
#include "scalezdown.xpm"
#include "scalezup.xpm"
#include "script.xpm"
#include "smooth.xpm"
#include "spreadsheet.xpm"
#include "title.xpm"
#include "vtk.xpm"
#include "worksheet.xpm"

==> labplot_1.6.0.2.orig.tar.gz: LabPlot-1.6.0.2/src/pixmaps/pixmap.h <==
//LabPlot : pixmap.h

#ifndef PIXMAP_H
#define PIXMAP_H

#include "arrange.xpm"
#include "arrow_down.xpm"
#include "arrow_left.xpm"
#include "arrow_right.xpm"
#include "arrow_up.xpm"
#include "autoscaleall.xpm"
#include "autoscalex.xpm"
#include "autoscaley.xpm"
#include "autoscalez.xpm"
#include "average.xpm"
#include "axes.xpm"
#include "baseline.xpm"
#include "capability.xpm"
#include "clear.xpm"
#include "clone.xpm"
#include "columnstat.xpm"
#include "compress.xpm"
#include "convolution.xpm"
#include "correlation.xpm"
#include "crosshair.xpm"
#include "deletePlot.xpm"
#include "differences.xpm"
#include "ellipse.xpm"
#include "evaluate.xpm"
#include "examples.xpm"
#include "explorer.xpm"
#include "exportim.xpm"
#include "exportps.xpm"
#include "export.xpm"
#include "fft.xpm"
#include "fit.xpm"
#include "fullscreen.xpm"
#include "graph.xpm"
#include "hankel.xpm"
#include "help.xpm"
#include "histogram.xpm"
#include "imagepro.xpm"
#include "image.xpm"
#include "import.xpm"
#include "integration.xpm"
#include "interpolation.xpm"
#include "label.xpm"
#include "laplace.xpm"
#include "legend.xpm"
#include "line.xpm"
#include "list_graphs.xpm"
#include "list_plots.xpm"
#include "mag_glass.xpm"
#include "mousepan.xpm"
#include "new3DData.xpm"
#include "new3DFunction.xpm"
#include "newData.xpm"
#include "newFunction.xpm"
#include "noise.xpm"
#include "objects.xpm"
#include "operations.xpm"
#include "overlay.xpm"
#include "peak.xpm"
#include "periodic.xpm"
#include "plot2d.xpm"
#include "plot3d.xpm"
#include "plotmask.xpm"
#include "plotpie.xpm"
#include "plotpolar.xpm"
#include "plotqwt3d.xpm"
#include "plotsurface.xpm"
#include "plotternary.xpm"
#include "project.xpm"
#include "prune.xpm"
#include "qsa.xpm"
#include "rect.xpm"
#include "redo.xpm"
#include "region.xpm"
#include "regression.xpm"
#include "rowstat.xpm"
#include "saveAs.xpm"
#include "scalexdown.xpm"
#include "scalexup.xpm"
#include "scaleydown.xpm"
#include "scaleyup.xpm"
#include "scalezdown.xpm"
#include "scalezup.xpm"
#include "script.xpm"
#include "seasonal.xpm"
#include "smooth.xpm"
#include "spreadsheet.xpm"
#include "tests.xpm"
#include "title.xpm"
#include "undo.xpm"
#include "wavelet.xpm"
#include "worksheet.xpm"
#include "zoomin.xpm"
#include "zoomout.xpm"

#endif // PIXMAP_H
